@@ -14,7 +14,7 @@ import sys
 import difflib
 import tempfile
 from conans import ConanFile, CMake
-from conans.errors import ConanException
+from conans.errors import ConanException, ConanInvalidConfiguration
 from conans.model.version import Version
 from conans import __version__ as conan_version
 
@@ -540,57 +540,76 @@ def get_builder(recipe_dir, args=None):
 
 
 def march_conan_manip(conanobj):
+    conanobj.output.info("KnuthConanFile.march_conan_manip() - 1")
     if conanobj.settings.arch != "x86_64":
-        return None
+        return (None, None, None)
+
+    conanobj.output.info("KnuthConanFile.march_conan_manip() - 2")
 
     if conanobj.options.get_safe("march_id") is None:
-        return None
+        return (None, None, None)
+
+    conanobj.output.info("KnuthConanFile.march_conan_manip() - 3")
 
     if conanobj.options.get_safe("march_strategy") is None:
-        return None
+        return (None, None, None)
+
+    conanobj.output.info("KnuthConanFile.march_conan_manip() - 4")
 
     conanobj.march_data = get_all_data(str(conanobj.settings.os),
                                        str(conanobj.settings.compiler),
                                        float(str(conanobj.settings.compiler.version)))
 
+    conanobj.output.info("KnuthConanFile.march_conan_manip() - 5")
+
+
     march_from = 'taken from cpuid'
     march_id = None
     march_names = None
     march_flags = None
 
     if conanobj.options.march_id == "_DUMMY_":
+        conanobj.output.info("KnuthConanFile.march_conan_manip() - 6")
+
         if conanobj.options.march_strategy == "optimized":
+            conanobj.output.info("KnuthConanFile.march_conan_manip() - 7")
             march_id = conanobj.march_data['comp_marchid']
             march_names = conanobj.march_data['comp_names']
             march_flags = conanobj.march_data['comp_flags']
         elif conanobj.options.march_strategy == "download_if_possible":
+            conanobj.output.info("KnuthConanFile.march_conan_manip() - 8")
             march_id = conanobj.march_data['comp_marchid']
             march_names = conanobj.march_data['comp_names']
             march_flags = conanobj.march_data['comp_flags']
             exts = conanobj.march_data['comp_exts']
             level3_exts = conanobj.march_data['level3_exts']
             if is_superset_of(exts, level3_exts):
+                conanobj.output.info("KnuthConanFile.march_conan_manip() - 9")
                 march_id = conanobj.march_data['level3_marchid']
                 march_names = conanobj.march_data['level3_names']
                 march_flags = conanobj.march_data['level3_flags']
         elif conanobj.options.march_strategy == "download_or_fail":
+            conanobj.output.info("KnuthConanFile.march_conan_manip() - 10")
             march_id = conanobj.march_data['comp_marchid']
             march_names = conanobj.march_data['comp_names']
             march_flags = conanobj.march_data['comp_flags']
             exts = conanobj.march_data['comp_exts']
             level3_exts = conanobj.march_data['level3_exts']
             if not is_superset_of(exts, level3_exts):
-                return (False, None, None, None)
+                conanobj.output.info("KnuthConanFile.march_conan_manip() - 11")
+                return (None, None, None)
 
         conanobj.options.march_id = march_id
     else:
+        conanobj.output.info("KnuthConanFile.march_conan_manip() - 12")
         march_id = conanobj.options.march_id
         march_from = 'user defined'
         #TODO(fernando): check for march_id errors
 
+    conanobj.output.info("KnuthConanFile.march_conan_manip() - 13")
     conanobj.output.info("Detected microarchitecture ID (%s): %s" % (march_from, march_id))
 
-    return (True, march_id, march_names, march_flags)
+    return (march_id, march_names, march_flags)
 
 
 def pass_march_to_compiler(conanobj, cmake):
@@ -703,10 +722,16 @@ class KnuthConanFile(ConanFile):
         # if self.conan_req_version != None and Version(conan_version) < Version(self.conan_req_version):
         #     raise Exception ("Conan version should be greater or equal than %s. Detected: %s." % (self.conan_req_version, conan_version))
 
+        self.output.info("KnuthConanFile.configure() - 1")
         ConanFile.configure(self)
+        self.output.info("KnuthConanFile.configure() - 2")
+
         if pure_c:
             del self.settings.compiler.libcxx               #Pure-C Library
 
+        self.output.info("KnuthConanFile.configure() - 3")
+
+
         if self.options.get_safe("currency") is not None:
             self.options["*"].currency = self.options.currency
             self.output.info("Compiling for currency: %s" % (self.options.currency,))
@@ -715,16 +740,34 @@ class KnuthConanFile(ConanFile):
             self.options["*"].db = self.options.db
             self.output.info("Compiling for DB: %s" % (self.options.db,))
 
+        self.output.info("KnuthConanFile.configure() - 4")
+
         # self._warn_missing_options()
 
         if self.settings.arch == "x86_64":
-            march_id = march_conan_manip(self)
+            self.output.info("KnuthConanFile.configure() - 5")
+
+            (march_id, march_names, march_flags) = march_conan_manip(self)
+
+            self.output.info(f"KnuthConanFile.configure() - march_id: {march_id} - march_names: {march_names} - march_flags: {march_flags}")
+
+            self.output.info("KnuthConanFile.configure() - 6")
+
             self.options["*"].march_id = march_id
+
+            self.output.info("KnuthConanFile.configure() - 7")
+
             self.options["*"].march_strategy = self.options.get_safe("march_strategy")
 
+
+            self.output.info("KnuthConanFile.configure() - 8")
+
+
             if self.options.get_safe("march_id") is not None:
                 self.options.march_id = march_id
 
+            self.output.info("KnuthConanFile.configure() - 9")
+
             #TODO(fernando)
             # if self.options.get_safe("march_id") is not None:
             #     self.output.info("Building microarchitecture ID: %s" % march_id)
